@@ -40,7 +40,7 @@ from ..io.reload import record_modules, watch
 from ..io.rest import REST_PROVIDERS
 from ..io.server import INDEX_HTML, get_static_routes, set_curdoc
 from ..io.state import state
-from ..util import fullpath
+from ..util import edit_readonly, fullpath
 
 log = logging.getLogger(__name__)
 
@@ -177,6 +177,11 @@ class Serve(_BkServe):
                 "or if they can access all applications as a guest."
             )
         )),
+        ('--root-path', Argument(
+            action  = 'store',
+            type    = str,
+            help    = "The root path can be used to handle cases where Panel is served behind a proxy."
+        )),
         ('--login-endpoint', Argument(
             action  = 'store',
             type    = str,
@@ -380,6 +385,17 @@ class Serve(_BkServe):
         config.global_loading_spinner = args.global_loading_spinner
         config.reuse_sessions = args.reuse_sessions
 
+        if args.root_path:
+            root_path = args.root_path
+            if not root_path.endswith('/'):
+                root_path += '/'
+            if not root_path.startswith('/'):
+                raise ValueError(
+                    '--root-path must start with a leading slash (`/`).'
+                )
+            with edit_readonly(state):
+                state.base_url = args.root_path
+
         if config.autoreload:
             for f in files:
                 watch(f)
