@@ -32,7 +32,7 @@ from bokeh.embed.bundle import (
 from bokeh.model import Model
 from bokeh.models import ImportedStyleSheet
 from bokeh.resources import Resources as BkResources, _get_server_urls
-from bokeh.settings import settings as _settings
+from bokeh.settings import _Unset, settings as _settings
 from jinja2.environment import Environment
 from jinja2.loaders import FileSystemLoader
 from markupsafe import Markup
@@ -180,7 +180,10 @@ def set_resource_mode(mode):
         yield
     finally:
         RESOURCE_MODE = old_mode
-        _settings.resources.set_value(old_resources)
+        if old_resources is _Unset:
+            _settings.resources.unset_value()
+        else:
+            _settings.resources.set_value(old_resources)
 
 def use_cdn() -> bool:
     return _settings.resources(default="server") != 'server' or state._is_pyodide
@@ -663,8 +666,13 @@ class Resources(BkResources):
         """
         from ..reactive import ReactiveCustomBase
         for model in param.concrete_descendents(ReactiveCustomBase).values():
-            if not (getattr(model, resource_type, None) and model._loaded()):
+            cls_files = getattr(model, resource_type, None)
+            if not (cls_files and model._loaded()):
                 continue
+            for cls in model.__mro__[1:]:
+                supcls_files = getattr(cls, resource_type, [])
+                if supcls_files == cls_files:
+                    model = cls
             for resource in getattr(model, resource_type, []):
                 if state.rel_path:
                     resource = resource.lstrip(state.rel_path+'/')
@@ -740,6 +748,7 @@ class Resources(BkResources):
 
         files = super().css_files
         self.extra_resources(files, '__css__')
+        self.extra_resources(files, '_bundle_css')
         css_files = self.adjust_paths([
             css for css in files if self.mode != 'inline' or not is_cdn_url(css)
         ])
