@@ -1,14 +1,6 @@
 from bokeh.core.enums import CalendarPosition
 from bokeh.core.properties import (
-    Bool,
-    Date,
-    Datetime,
-    Either,
-    Enum,
-    List,
-    Nullable,
-    String,
-    Tuple,
+    Bool, Date, Datetime, Either, Enum, List, Nullable, String, Tuple,
 )
 from bokeh.models.widgets.inputs import InputWidget
 
@@ -18,7 +10,7 @@ class DatetimePicker(InputWidget):
 
     '''
 
-    value = String(help="""
+    value = Nullable(String, help="""
     The initial or picked date.
     """)
 
@@ -30,15 +22,15 @@ class DatetimePicker(InputWidget):
     Optional latest allowable date.
     """)
 
-    disabled_dates = List(Either(Date, Datetime, Tuple(Date, Date), Tuple(Datetime, Datetime)), default=[], help="""
+    disabled_dates = Nullable(List(Either(Date, Datetime, Tuple(Date, Date), Tuple(Datetime, Datetime))), default=None, help="""
     A list of dates of ``(start, end)`` date ranges to make unavailable for
-    selection. All other dates will be avalable.
+    selection. All other dates will be available.
 
     .. note::
         Only one of ``disabled_dates`` and ``enabled_dates`` should be specified.
     """)
 
-    enabled_dates = List(Either(Date, Datetime, Tuple(Date, Date), Tuple(Datetime, Datetime)), default=[], help="""
+    enabled_dates = Nullable(List(Either(Date, Datetime, Tuple(Date, Date), Tuple(Datetime, Datetime))), default=None, help="""
     A list of dates of ``(start, end)`` date ranges to make available for
     selection. All other dates will be unavailable.
 
